vmd — Remote Tcl commands in VMD — GromacsWrapper 0.6.1 documentation

# `vmd` — Remote Tcl commands in VMD

The `vmd` module contains a very simple client that can connect to a locally running server process in VMD. This allows running VMD Tcl commands remotely. See VMD Tcl Text Commands for all available commands.

The `vmd` module is independent from `gromacs` and distribute for convenience. It can be used to implement additional visualization and analysis tasks.

## VMD control

Simple client to transmit Tcl commands to a server running in VMD.

VMD and the server run locally and can be started from the module. Once the server is running, one can use `vmd.client` to communicate with the server process via a local socket.

### Example

Start a VMD server and connect:

    from vmd.control import *
    VMD = server()
    VMD.command('molecule new load 1AKE')

or start an interactive Tcl session connected to a running VMD server process:

    interactive(host)
    asyncore.loop()      # necessary

See VMD Tcl Text Commands for all available commands.